@@ -1,51 +1,53 @@
 #' Check if parameter value is valid.
-#' 
+#'
 #' Check if a parameter value satisfies the constraints of the
-#' parameter description. This includes the \code{requires} expressions,
-#' if \code{par} is a \code{\link{ParamSet}}. If \code{requires} is not satisfied,
-#' the parameter value must be set to scalar \code{NA} to be still feasible, a single scalar even in a 
+#' parameter description. This includes the \code{requires} expressions and
+#' the \code{forbidden} expression, if \code{par} is a \code{\link{ParamSet}}.
+#' If \code{requires} is not satisfied,
+#' the parameter value must be set to scalar \code{NA} to be still feasible, a single scalar even in a
 #' case of a vector parameter.
-#' 
-#' @param par [\code{\link{Param}} | \code{\link{ParamSet}}]\cr
-#'   Parameter or parameter set.
+#'
+#' @template arg_par_or_set
 #' @param x [any] \cr
-#'   Single value to check. 
+#'   Single value to check.
 #'   For a parameter set this must be a list in the correct order.
 #' @return logical(1)
-#' @examples 
-#' p <- makeNumericParam("x", lower=-1, upper=1)
-#' isFeasible(p,0) # True
-#' isFeasible(p,2) # False, out of bounds
-#' isFeasible(p,"a") # False, wrong type
+#' @examples
+#' p = makeNumericParam("x", lower = -1, upper = 1)
+#' isFeasible(p, 0) # True
+#' isFeasible(p, 2) # False, out of bounds
+#' isFeasible(p, "a") # False, wrong type
 #' # now for parameter sets
-#' ps <- makeParamSet(
-#'   makeNumericParam("x",lower=-1,upper=1),
-#'   makeDiscreteParam("y", values=c("a","b"))
+#' ps = makeParamSet(
+#'   makeNumericParam("x", lower = -1, upper = 1),
+#'   makeDiscreteParam("y", values = c("a", "b"))
 #' )
-#' isFeasible(ps, list(0,"a")) # True
-#' isFeasible(ps, list("a",0)) # False, wrong order 
+#' isFeasible(ps, list(0, "a")) # True
+#' isFeasible(ps, list("a", 0)) # False, wrong order
 #' @export
 isFeasible = function(par, x) {
   UseMethod("isFeasible")
 }
 
-#' @S3method isFeasible Param
+#' @export
 isFeasible.Param = function(par, x) {
   # we dont have to consider requires here, it is not a param set
   constraintsOkParam(par, x)
 }
 
-#' @S3method isFeasible LearnerParam
+#' @export
 isFeasible.LearnerParam = function(par, x) {
   # we dont have to consider requires here, it is not a param set
   constraintsOkLearnerParam(par, x)
 }
 
-#' @S3method isFeasible ParamSet
+#' @export
 isFeasible.ParamSet = function(par, x) {
   if (!(is.list(x) && length(x) == length(par$pars) && all(names(x) == names(par$pars))))
     return(FALSE)
-  #FIXME very slow  
+  if (isForbidden(par, x))
+    return(FALSE)
+  #FIXME: very slow
   for (i in seq_along(par$pars)) {
     p = par$pars[[i]]
     v = x[[i]]
@@ -87,13 +89,13 @@ constraintsOkParam = function(par, x) {
     is.numeric(x) && length(x) == par$len && all(is.finite(x) & x >= par$lower & x <= par$upper & x == as.integer(x))
   else if (type == "discrete")
     inValues(x)
-  else if (type == "discretevector") 
+  else if (type == "discretevector")
     is.list(x) && length(x) == par$len && all(sapply(x, inValues))
-  else if (type == "logical") 
+  else if (type == "logical")
     is.logical(x) && length(x) == 1 && !is.na(x)
-  else if (type == "logicalvector") 
+  else if (type == "logicalvector")
     is.logical(x) && length(x) == par$len && !any(is.na(x))
-  else if (type == "function") 
+  else if (type == "function")
     is.function(x)
 }
 
@@ -111,10 +113,10 @@ constraintsOkLearnerParam = function(par, x) {
     is.list(x) && (is.na(par$len) || length(x) == par$len) && all(sapply(x, inValues))
   else
     constraintsOkParam(par, x)
-}    
+}
 
 # is the requires part of the ith param valid for value x (x[[i]] is value or ith param)
 # assumes that param actually has a requires part
 requiresOk = function(par.set, x, i) {
-  eval(par.set$pars[[i]]$requires, envir=x)
-}
\ No newline at end of file
+  eval(par.set$pars[[i]]$requires, envir = x)
+}
